@@ -1,13 +1,26 @@
+from typing import Optional
 from . import base_api_core
 
 import time
 
 
 class ActiveBackupBusiness(base_api_core.Core):
-    def __init__(self, ip_address, port, username, password, secure=False, cert_verify=False, dsm_version=7, debug=True, otp_code=None):
-        super(ActiveBackupBusiness, self).__init__(ip_address, port, username, password, secure, cert_verify, dsm_version, debug, otp_code)
+    def __init__(self,
+                 ip_address: str,
+                 port: str,
+                 username: str,
+                 password: str,
+                 secure: bool = False,
+                 cert_verify: bool = False,
+                 dsm_version: int = 7,
+                 debug: bool = True,
+                 otp_code: Optional[str] = None
+                 ) -> None:
+        super(ActiveBackupBusiness, self).__init__(ip_address, port, username, password, secure, cert_verify,
+                                                   dsm_version, debug, otp_code)
+        return
 
-    def list_vm_hypervisor(self):
+    def list_vm_hypervisor(self) -> dict[str, object] | str:
         api_name = 'SYNO.ActiveBackup.Inventory'
         info = self.gen_list[api_name]
         api_path = info['path']
@@ -17,7 +30,7 @@ class ActiveBackupBusiness(base_api_core.Core):
 
         return self.request_data(api_name, api_path, req_param)
 
-    def list_device_transfer_size(self):
+    def list_device_transfer_size(self) -> dict[str, object] | str:
         api_name = 'SYNO.ActiveBackup.Overview'
         info = self.gen_list[api_name]
         api_path = info['path']
