@@ -1,3 +1,4 @@
+from typing import Optional, Any
 import os
 import time
 from datetime import datetime
@@ -11,39 +12,52 @@ from . import auth as syn
 
 class FileStation:
 
-    def __init__(self, ip_address, port, username, password, secure=False, cert_verify=False, dsm_version=7, debug=True, otp_code=None, interactive_output=True):
+    def __init__(self,
+                 ip_address: str,
+                 port: str,
+                 username: str,
+                 password: str,
+                 secure: bool = False,
+                 cert_verify: bool = False,
+                 dsm_version: int = 7,
+                 debug: bool = True,
+                 otp_code: Optional[str] = None,
+                 interactive_output: bool = True
+                 ) -> None:
 
-        self.session = syn.Authentication(ip_address, port, username, password, secure, cert_verify, dsm_version, debug, otp_code)
+        self.session: syn.Authentication = syn.Authentication(ip_address, port, username, password, secure, cert_verify,
+                                                              dsm_version, debug, otp_code)
 
-        self._dir_taskid = ''
-        self._dir_taskid_list = []
-        self._md5_calc_taskid = ''
-        self._md5_calc_taskid_list = []
-        self._search_taskid = ''
-        self._search_taskid_list = []
-        self._copy_move_taskid = ''
-        self._copy_move_taskid_list = []
-        self._delete_taskid = ''
-        self._delete_taskid_list = []
-        self._extract_taskid = ''
-        self._extract_taskid_list = []
-        self._compress_taskid = ''
-        self._compress_taskid_list = []
+        self._dir_taskid: str = ''
+        self._dir_taskid_list: list[str] = []
+        self._md5_calc_taskid: str = ''
+        self._md5_calc_taskid_list: list[str] = []
+        self._search_taskid: str = ''
+        self._search_taskid_list: list[str] = []
+        self._copy_move_taskid: str = ''
+        self._copy_move_taskid_list: list[str] = []
+        self._delete_taskid: str = ''
+        self._delete_taskid_list: list[str] = []
+        self._extract_taskid: str = ''
+        self._extract_taskid_list: list[str] = []
+        self._compress_taskid: str = ''
+        self._compress_taskid_list: list[str] = []
         self.request_data = self.session.request_data
-        
+
         self.session.login('FileStation')
         self.session.get_api_list('FileStation')
 
-        self.file_station_list = self.session.app_api_list
-        self._sid = self.session.sid
-        self.base_url = self.session.base_url
+        self.file_station_list: Any = self.session.app_api_list
+        self._sid: str = self.session.sid
+        self.base_url: str = self.session.base_url
 
-        self.interactive_output = interactive_output
+        self.interactive_output: bool = interactive_output
 
-    def logout(self):
+    def logout(self) -> None:
         self.session.logout('FileStation')
+        return
 
-    def get_info(self):
+    def get_info(self) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Info'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -51,8 +65,14 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def get_list_share(self, additional=None, offset=None, limit=None, sort_by=None,
-                       sort_direction=None, onlywritable=False):
+    def get_list_share(self,
+                       additional: Optional[str | list[str]] = None,
+                       offset: Optional[int] = None,
+                       limit: Optional[int] = None,
+                       sort_by: Optional[str] = None,
+                       sort_direction: Optional[str] = None,
+                       onlywritable: bool = False
+                       ) -> dict[str, object] | str:
 
         api_name = 'SYNO.FileStation.List'
         info = self.file_station_list[api_name]
@@ -74,8 +94,16 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def get_file_list(self, folder_path=None, offset=None, limit=None, sort_by=None,
-                      sort_direction=None, pattern=None, filetype=None, goto_path=None, additional=None):
+    def get_file_list(self,
+                      folder_path: Optional[str] = None,
+                      offset: Optional[int] = None,
+                      limit: Optional[int] = None,
+                      sort_by: Optional[str] = None,
+                      sort_direction: Optional[str] = None,
+                      pattern: Optional[str] = None,
+                      filetype: Optional[str] = None,
+                      goto_path: Optional[str] = None,
+                      additional: Optional[str | list[str]] = None) -> dict[str, object] | str:
 
         api_name = 'SYNO.FileStation.List'
         info = self.file_station_list[api_name]
@@ -103,7 +131,10 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def get_file_info(self, path=None, additional=None):
+    def get_file_info(self,
+                      path: Optional[str] = None,
+                      additional: Optional[str | list[str]] = None
+                      ) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.List'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -131,9 +162,23 @@ class FileStation:
     # TODO  all working if specify extension check if correct [pattern, extension]
     #  it works if you put extension='...'
 
-    def search_start(self, folder_path=None, recursive=None, pattern=None, extension=None, filetype=None,
-                     size_from=None, size_to=None, mtime_from=None, mtime_to=None, crtime_from=None, crtime_to=None,
-                     atime_from=None, atime_to=None, owner=None, group=None):
+    def search_start(self,
+                     folder_path: Optional[str] = None,
+                     recursive: Optional[bool] = None,
+                     pattern: Optional[str] = None,
+                     extension: Optional[str] = None,
+                     filetype: Optional[str] = None,
+                     size_from: Optional[int] = None,
+                     size_to: Optional[int] = None,
+                     mtime_from: Optional[str | int] = None,
+                     mtime_to: Optional[str | int] = None,
+                     crtime_from: Optional[str | int] = None,
+                     crtime_to: Optional[str | int] = None,
+                     atime_from: Optional[str | int] = None,
+                     atime_to: Optional[str | int] = None,
+                     owner: Optional[str] = None,
+                     group: Optional[str] = None
+                     ) -> dict[str, object] | str:
 
         api_name = 'SYNO.FileStation.Search'
         info = self.file_station_list[api_name]
@@ -180,8 +225,15 @@ class FileStation:
 
         return output
 
-    def get_search_list(self, task_id=None, filetype=None, limit=None, sort_by=None, sort_direction=None,
-                        offset=None, additional=None):
+    def get_search_list(self,
+                        task_id: str,
+                        filetype: Optional[str] = None,
+                        limit: Optional[int] = None,
+                        sort_by: Optional[str] = None,
+                        sort_direction: Optional[str] = None,
+                        offset: Optional[int] = None,
+                        additional: Optional[str | list[str]] = None
+                        ) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Search'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -210,7 +262,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def stop_search_task(self, taskid=None):
+    def stop_search_task(self, taskid: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Search'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -223,7 +275,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def stop_all_search_task(self):
+    def stop_all_search_task(self) -> str:
         api_name = 'SYNO.FileStation.Search'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -239,8 +291,14 @@ class FileStation:
 
         return 'All task are stopped'
 
-    def get_mount_point_list(self, mount_type=None, offset=None, limit=None, sort_by=None,
-                             sort_direction=None, additional=None):
+    def get_mount_point_list(self,
+                             mount_type: Optional[str] = None,
+                             offset: Optional[int] = None,
+                             limit: Optional[int] = None,
+                             sort_by: Optional[str] = None,
+                             sort_direction: Optional[str] = None,
+                             additional: Optional[str | list[str]] = None
+                             ) -> dict[str, object] | str:
 
         api_name = 'SYNO.FileStation.VirtualFolder'
         info = self.file_station_list[api_name]
@@ -265,8 +323,13 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def get_favorite_list(self, offset=None, limit=None, sort_by=None,
-                          status_filter=None, additional=None):
+    def get_favorite_list(self,
+                          offset: Optional[int] = None,
+                          limit: Optional[int] = None,
+                          sort_by: Optional[str] = None,
+                          status_filter: Optional[str] = None,
+                          additional: Optional[str | list[str]] = None
+                          ) -> dict[str, object] | str:
 
         api_name = 'SYNO.FileStation.Favorite'
         info = self.file_station_list[api_name]
@@ -288,7 +351,11 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def add_a_favorite(self, path=None, name=None, index=None):
+    def add_a_favorite(self,
+                       path: str,
+                       name: Optional[str] = None,
+                       index: Optional[int] = None
+                       ) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Favorite'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -304,7 +371,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def delete_a_favorite(self, path=None):
+    def delete_a_favorite(self, path: Optional[str] = None) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Favorite'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -317,7 +384,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def clear_broken_favorite(self):
+    def clear_broken_favorite(self) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Favorite'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -325,7 +392,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def edit_favorite_name(self, path=None, new_name=None):
+    def edit_favorite_name(self, path: str, new_name: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Favorite'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -343,7 +410,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def replace_all_favorite(self, path=None, name=None):
+    def replace_all_favorite(self, path: str | list[str], name: str | list[str]):
         api_name = 'SYNO.FileStation.Favorite'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -367,7 +434,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def start_dir_size_calc(self, path=None):
+    def start_dir_size_calc(self, path: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.DirSize'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -400,8 +467,7 @@ class FileStation:
 
         return output
 
-
-    def stop_dir_size_calc(self, taskid=None):
+    def stop_dir_size_calc(self, taskid: str) -> str:
         api_name = 'SYNO.FileStation.DirSize'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -417,7 +483,7 @@ class FileStation:
 
         return 'The task has been stopped'
 
-    def get_dir_status(self, taskid=None):
+    def get_dir_status(self, taskid: Optional[str] = None) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.DirSize'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -428,7 +494,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def start_md5_calc(self, file_path=None):
+    def start_md5_calc(self, file_path: str) -> str | dict[str, object]:
         api_name = 'SYNO.FileStation.MD5'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -451,7 +517,7 @@ class FileStation:
 
         return output
 
-    def get_md5_status(self, taskid=None):
+    def get_md5_status(self, taskid: Optional[str] = None) -> str | dict[str, object]:
         api_name = 'SYNO.FileStation.MD5'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -466,7 +532,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def stop_md5_calc(self, taskid=None):
+    def stop_md5_calc(self, taskid: str) -> str:
         api_name = 'SYNO.FileStation.DirSize'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -482,7 +548,12 @@ class FileStation:
 
         return 'The task has been stopped'
 
-    def check_permissions(self, path=None, filename=None, overwrite=None, create_only=None):
+    def check_permissions(self,
+                          path: str,
+                          filename: str,
+                          overwrite: Optional[bool] = None,
+                          create_only: Optional[bool] = None
+                          ) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.CheckPermission'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -501,7 +572,13 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def upload_file(self, dest_path, file_path, create_parents=True, overwrite=True, verify=False):
+    def upload_file(self,
+                    dest_path: str,
+                    file_path: str,
+                    create_parents: bool = True,
+                    overwrite: bool = True,
+                    verify: bool = False
+                    ) -> str | tuple[int, dict[str, object]]:
         api_name = 'SYNO.FileStation.Upload'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -528,7 +605,7 @@ class FileStation:
             else:
                 return r.status_code, r.json()
 
-    def get_shared_link_info(self, link_id=None):
+    def get_shared_link_info(self, link_id: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Sharing'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -541,8 +618,14 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def get_shared_link_list(self, offset=None, limit=None, sort_by=None,
-                             sort_direction=None, force_clean=None):
+    def get_shared_link_list(self,
+                             offset: Optional[int] = None,
+                             limit: Optional[int] = None,
+                             sort_by: Optional[str] = None,
+                             sort_direction: Optional[str] = None,
+                             force_clean: Optional[bool] = None
+                             ) -> dict[str, object] | str:
+
         api_name = 'SYNO.FileStation.Sharing'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -555,8 +638,13 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def create_sharing_link(self, path=None, password=None, date_expired=None,
-                            date_available=None, expire_times=0):
+    def create_sharing_link(self,
+                            path: str,
+                            password: Optional[str] = None,
+                            date_expired: Optional[str | int] = None,
+                            date_available: Optional[str | int] = None,
+                            expire_times: int = 0
+                            ) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Sharing'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -572,7 +660,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def delete_shared_link(self, link_id=None):
+    def delete_shared_link(self, link_id: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Sharing'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -585,7 +673,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def clear_invalid_shared_link(self):
+    def clear_invalid_shared_link(self) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Sharing'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -593,8 +681,13 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def edit_shared_link(self, link_id=None, password=None, date_expired=None,
-                         date_available=None, expire_times=0):
+    def edit_shared_link(self,
+                         link_id: str,
+                         password: Optional[str] = None,
+                         date_expired: Optional[str | int] = None,
+                         date_available: Optional[str | int] = None,
+                         expire_times: int = 0
+                         ) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Sharing'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -612,7 +705,12 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def create_folder(self, folder_path=None, name=None, force_parent=None, additional=None):
+    def create_folder(self,
+                      folder_path: str | list[str],
+                      name: str | list[str],
+                      force_parent: Optional[bool] = None,
+                      additional: Optional[str | list[str]] = None
+                      ) -> str | dict[str, object]:
         api_name = 'SYNO.FileStation.CreateFolder'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -655,7 +753,12 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def rename_folder(self, path=None, name=None, additional=None, search_taskid=None):
+    def rename_folder(self,
+                      path: str | list[str],
+                      name: str | list[str],
+                      additional: Optional[str | list[str]] = None,
+                      search_taskid: Optional[str] = None
+                      ) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Rename'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -696,8 +799,14 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def start_copy_move(self, path=None, dest_folder_path=None, overwrite=None, remove_src=None,
-                        accurate_progress=None, search_taskid=None):
+    def start_copy_move(self,
+                        path: str | list[str],
+                        dest_folder_path: str | list[str],
+                        overwrite: Optional[bool] = None,
+                        remove_src: Optional[bool] = None,
+                        accurate_progress: Optional[bool] = None,
+                        search_taskid: Optional[str] = None
+                        ) -> str | dict[str, object]:
         api_name = 'SYNO.FileStation.CopyMove'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -744,8 +853,7 @@ class FileStation:
 
         return output
 
-
-    def get_copy_move_status(self, taskid=None):
+    def get_copy_move_status(self, taskid: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.CopyMove'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -758,7 +866,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def stop_copy_move_task(self, taskid=None):
+    def stop_copy_move_task(self, taskid: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.CopyMove'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -773,7 +881,12 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def start_delete_task(self, path=None, accurate_progress=None, recursive=None, search_taskid=None):
+    def start_delete_task(self,
+                          path: str | list[str],
+                          accurate_progress: Optional[bool] = None,
+                          recursive: Optional[bool] = None,
+                          search_taskid: Optional[str] = None
+                          ) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Delete'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -808,8 +921,7 @@ class FileStation:
 
         return output
 
-
-    def get_delete_status(self, taskid=None):
+    def get_delete_status(self, taskid: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Delete'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -822,7 +934,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def stop_delete_task(self, taskid=None):
+    def stop_delete_task(self, taskid: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Delete'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -837,7 +949,10 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def delete_blocking_function(self, path=None, recursive=None, search_taskid=None):
+    def delete_blocking_function(self,
+                                 path: str,
+                                 recursive: Optional[bool] = None,
+                                 search_taskid: Optional[str] = None) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Delete'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -863,8 +978,16 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def start_extract_task(self, file_path=None, dest_folder_path=None, overwrite=None, keep_dir=None,
-                           create_subfolder=None, codepage=None, password=None, item_id=None):
+    def start_extract_task(self,
+                           file_path: str,
+                           dest_folder_path: str,
+                           overwrite: Optional[bool] = None,
+                           keep_dir: Optional[bool] = None,
+                           create_subfolder: Optional[bool] = None,
+                           codepage: Optional[str] = None,
+                           password: Optional[str] = None,
+                           item_id: Optional[str] = None
+                           ) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Extract'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -895,7 +1018,7 @@ class FileStation:
 
         return output
 
-    def get_extract_status(self, taskid=None):
+    def get_extract_status(self, taskid: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Extract'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -908,7 +1031,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def stop_extract_task(self, taskid=None):
+    def stop_extract_task(self, taskid: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Extract'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -923,8 +1046,16 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def get_file_list_of_archive(self, file_path=None, offset=None, limit=None, sort_by=None,
-                                 sort_direction=None, codepage=None, password=None, item_id=None):
+    def get_file_list_of_archive(self,
+                                 file_path: str,
+                                 offset: Optional[int] = None,
+                                 limit: Optional[int] = None,
+                                 sort_by: Optional[str] = None,
+                                 sort_direction: Optional[str] = None,
+                                 codepage: Optional[str] = None,
+                                 password: Optional[str] = None,
+                                 item_id: Optional[str] = None
+                                 ) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Extract'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -940,8 +1071,14 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def start_file_compression(self, path=None, dest_file_path=None, level=None, mode=None,
-                               compress_format=None, password=None):
+    def start_file_compression(self,
+                               path: str | list[str],
+                               dest_file_path: str,
+                               level: Optional[int] = None,
+                               mode: Optional[str] = None,
+                               compress_format: Optional[str] = None,
+                               password: Optional[str] = None
+                               ) -> dict[str, object] | str | tuple[str]:
         api_name = 'SYNO.FileStation.Compress'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -975,9 +1112,9 @@ class FileStation:
 
         self._compress_taskid = self.request_data(api_name, api_path, req_param)['data']['taskid']
 
-        message =('You can now check the status of request with '
-                  'get_compress_status() , your id is: '
-                  + self._compress_taskid)
+        message = ('You can now check the status of request with '
+                   'get_compress_status() , your id is: '
+                   + self._compress_taskid)
         if self.interactive_output:
             output = message
         else:
@@ -985,8 +1122,7 @@ class FileStation:
 
         return output
 
-
-    def get_compress_status(self, taskid=None):
+    def get_compress_status(self, taskid: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Compress'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -999,7 +1135,7 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def stop_compress_task(self, taskid=None):
+    def stop_compress_task(self, taskid: str) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.Compress'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -1012,8 +1148,13 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def get_list_of_all_background_task(self, offset=None, limit=None, sort_by=None,
-                                        sort_direction=None, api_filter=None):
+    def get_list_of_all_background_task(self,
+                                        offset: Optional[int] = None,
+                                        limit: Optional[int] = None,
+                                        sort_by: Optional[str] = None,
+                                        sort_direction: Optional[str] = None,
+                                        api_filter: Optional[str] = None
+                                        ) -> dict[str, object] | str:
         api_name = 'SYNO.FileStation.BackgroundTask'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -1033,7 +1174,13 @@ class FileStation:
 
         return self.request_data(api_name, api_path, req_param)
 
-    def get_file(self, path=None, mode=None, dest_path=".", chunk_size=8192, verify=False):
+    def get_file(self,
+                 path: str,
+                 mode: str,
+                 dest_path: str = ".",
+                 chunk_size: int = 8192,
+                 verify: bool = False
+                 ) -> Optional[str]:
 
         api_name = 'SYNO.FileStation.Download'
         info = self.file_station_list[api_name]
@@ -1045,7 +1192,7 @@ class FileStation:
         session = requests.session()
 
         url = ('%s%s' % (self.base_url, api_path)) + '?api=%s&version=%s&method=download&path=%s&mode=%s&_sid=%s' % (
-                api_name, info['maxVersion'], parse.quote_plus(path), mode, self._sid)
+            api_name, info['maxVersion'], parse.quote_plus(path), mode, self._sid)
 
         if mode is None:
             return 'Enter a valid mode (open / download)'
